@@ -11,7 +11,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/builtins.c,v 1.34 2020/03/27 08:03:38 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/builtins.c,v 1.35 2022/09/28 21:13:52 tg Exp $");
 
 #ifndef JUPPRC_BUILTIN_NAME
 #define JUPPRC_BUILTIN_NAME "jupprc"
@@ -84,8 +84,8 @@ const unsigned char * const builtins[] = {
 		"\\i \\i \\b^KX\\b save   \\b^KB\\b begin  \\b^KV\\b move  \\b^QF\\b find first         \\b^G\\b  >char  \\b^QT\\b <line \\i \\i\n"
 		"\\i \\i \\b^KQ\\b abort  \\b^KK\\b end    \\b^KC\\b copy  \\b^L\\b  find next          \\b^[o\\b <word  \\b^QY\\b >line \\i \\i\n"
 		"\\i \\i \\u\\bMISC\\b\\u       \\b^KL\\b line   \\b^KY\\b kill  \\b^QA\\b find and replace   \\b^T\\b  >word  \\b^[Y\\b yank  \\i \\i\n"
-		"\\i \\i \\b^QM\\b math   \\b^KH\\b hide   \\b^K/\\b pipe  \\b^QG\\b char backwards  \\u\\bSHELL\\b\\u        \\u\\bFILE\\b\\u       \\i \\i\n"
-		"\\i \\i \\b^O\\b  options   \\u\\bQUOTE\\b\\u    \\u\\bBUFFER\\b\\u   \\b^QF\\b char forwards   \\b^KZ\\b suspend  \\b^KS\\b save\\das\\d \\i \\i\n"
+		"\\i \\i \\b^QM\\b math   \\b^KH\\b hide   \\b^K/\\b pipe  \\b^QG\\b byte backwards  \\u\\bSHELL\\b\\u        \\u\\bFILE\\b\\u       \\i \\i\n"
+		"\\i \\i \\b^O\\b  options   \\u\\bQUOTE\\b\\u    \\u\\bBUFFER\\b\\u   \\b^QH\\b byte forwards   \\b^KZ\\b suspend  \\b^KS\\b save\\das\\d \\i \\i\n"
 		"\\i \\i \\b^[P\\b pastemode  \\b`\\b Ctrl  \\b^U\\b undo  \\b^[R\\b incremental b.  \\b^K'\\b window   \\b^KR\\b import \\i \\i\n"
 		"\\i \\i \\b^[-\\b cmdprompt \\b^P\\b Meta  \\b^^\\b redo  \\b^[T\\b incr. forwards  \\b^['\\b command  \\b^KW\\b export \\i \\i\n"
 		"}\n"
@@ -170,7 +170,7 @@ const unsigned char * const builtins[] = {
 		"\\i \\i go to \\uhttp://sf.net/projects/joe-editor/\\u for upstream bug reports. JUPP 2.8 \\i \\i\n"
 		"\\i \\i for DOS compiled by A. Totlis, packed with LHarc 2.13; JUPP 3.x for UNIX\\d(R)\\d \\i \\i\n"
 		"\\i \\i at \\uhttp://mirbsd.de/jupp\\u and by \\bThorsten \"\\dmirabilos\\d\" Glaser <\\utg@mirbsd.org\\u>\\b \\i \\i\n"
-		"\\i \\i @(#) blt_in 2020-01-31; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
+		"\\i \\i @(#) blt_in 2022-03-12; 3.1; autoCR-LF; UTF-8 via locale; per-file encoding \\i \\i\n"
 		"}\n"
 		"\n"
 		"{CharTable\n"
