@@ -12,7 +12,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/charmap.c,v 1.33 2020/10/30 03:11:04 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/charmap.c,v 1.34 2022/09/28 20:20:17 tg Exp $");
 
 #include <stdlib.h>
 #include <string.h>
@@ -1214,13 +1214,13 @@ process_builtin(const struct builtin_charmap *builtin)
 static void
 load_builtins(void)
 {
-	union charmap *map;
+	struct charmap_head *map;
 
 	/* install UTF-8 map (ties into i18n module) */
 	map = malloc(sizeof(struct charmap_head));
-	map->head.cs = NULL;
-	map->head.next = charmaps;
-	charmaps = map;
+	map->cs = NULL;
+	map->next = charmaps;
+	charmaps = (union charmap *)map;
 }
 
 /* Parse character map file */
