@@ -3,13 +3,15 @@
  *	Copyright
  *		(C) 1992 Joseph H. Allen
  *		(C) 2001 Marek 'Marx' Grac
+ *	Copyright © 2012, 2017, 2018
+ *		mirabilos <m@mirbsd.org>
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/help.c,v 1.18 2018/01/08 00:40:44 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/help.c,v 1.20 2022/07/20 22:51:22 tg Exp $");
 
 #include <stdlib.h>
 #include <string.h>
@@ -61,7 +63,7 @@ help_init(const unsigned char *filename)
 			}
 			/* end of help screen */
 			if (buf[0] != /*{*/'}') {
-				fprintf(stderr, /*{*/ "\nHelp file '%s' is not properly ended with } on new line.\nDo you want to accept incomplete help screen (y/n)?", filename);
+				fprintf(stderr, /*{*/ "\nHelp file '%s' is not properly ended with } on new line.\nDo you want to accept incomplete help screen (y,n)? ", filename);
 				fflush(stderr);
 				if (!fgets((char *)buf, sizeof(buf), stdin) ||
 				    (buf[0] | 0x20) != 'y') {
@@ -83,7 +85,7 @@ help_init(const unsigned char *filename)
 			help_actual = tmp;
 		}
 	}
-	fprintf(stderr, "done\n");
+	fprintf(stderr, " done\n");
  out:
 	/* close help file */
 	jfclose(fd);
