@@ -1,4 +1,4 @@
-#define JUPP_IS_COPYRIGHT_C_BY "2020 mirabilos"
+#define JUPP_IS_COPYRIGHT_C_BY "2022 mirabilos"
 
 /*-
  * Copyright (c) 2004ff. Thorsten Glaser
@@ -32,7 +32,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/main.c,v 1.47 2020/03/27 06:30:16 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/main.c,v 1.49 2022/07/21 00:18:00 tg Exp $");
 
 #include <fcntl.h>
 #include <string.h>
@@ -63,7 +63,9 @@ extern unsigned char *joeterm;
 int help = 0;			/* Set to have help on when starting */
 int nonotice = 0;		/* Set to prevent copyright notice */
 int orphan = 0;
-unsigned char *exmsg = NULL;		/* Message to display when exiting the editor */
+int main_rv = 0;
+extern unsigned char closedall;
+unsigned char *exmsg = NULL;	/* Message to display when exiting the editor */
 
 SCREEN *maint;			/* Main edit screen */
 
@@ -91,7 +93,7 @@ void dofollows(void)
 /* Update screen */
 
 int dostaupd = 1;
-extern int staupd;
+extern unsigned char staupd;
 
 void edupd(int flg)
 {
@@ -124,8 +126,8 @@ void edupd(int flg)
 	staupd = 0;
 }
 
-static int ahead = 0;
-static int ungot = 0;
+static unsigned char ahead = 0;
+static unsigned char ungot = 0;
 static int ungotc = 0;
 
 void nungetc(int c)
@@ -187,6 +189,23 @@ int edloop(int flg)
 
 unsigned char **mainenv;
 
+static void
+genjuppverstr(void)
+{
+	int uninvert = fdefault.hmsg &&
+	    fdefault.hmsg[0] == '\\' &&
+	    fdefault.hmsg[1] == 'i';
+
+	joe_snprintf_5((char *)msgbuf, JOE_MSGBUFSIZE,
+	    "\\i[ Joe's Own Editor v" VERSION
+	    " | %s | %s " JUPP_IS_COPYRIGHT_C_BY " ]%s%s%s",
+	    joe_mapname(locale_map),
+	    joe_maputf(locale_map) ? "©" : "(c)",
+	    uninvert ? "\\i " : fdefault.hmsg ? " " : "",
+	    uninvert ? fdefault.hmsg + 2 : fdefault.hmsg ?
+	    fdefault.hmsg : "", uninvert ? "" : "\\i");
+}
+
 static int
 main_init(char **argv, char **envp, SCRN **np)
 {
@@ -236,7 +255,7 @@ main_init(char **argv, char **envp, SCRN **np)
 		if (c == 1) {
 			unsigned char buf[8];
 
-			fprintf(stderr, "There were errors in '%s'.  Use it anyway?", s);
+			fprintf(stderr, "There were errors in '%s'. Use anyway (y,n)? ", s);
 			fflush(stderr);
 			if (fgets((char *)buf, 8, stdin) != NULL &&
 			    (buf[0] | 0x20) == 'y')
@@ -255,7 +274,7 @@ main_init(char **argv, char **envp, SCRN **np)
 		if (c == 1) {
 			unsigned char buf[8];
 
-			fprintf(stderr, "There were errors in '%s'.  Use it anyway?", s);
+			fprintf(stderr, "There were errors in '%s'. Use anyway (y,n)? ", s);
 			fflush(stderr);
 			if (fgets((char *)buf, 8, stdin) != NULL &&
 			    (buf[0] | 0x20) == 'y')
@@ -274,7 +293,7 @@ main_init(char **argv, char **envp, SCRN **np)
 	if (c == 1) {
 		unsigned char buf[8];
 
-		fprintf(stderr, "There were errors in '%s'.  Use it anyway?", s);
+		fprintf(stderr, "There were errors in '%s'. Use anyway (y,n)? ", s);
 		fflush(stderr);
 		if (fgets((char *)buf, 8, stdin) != NULL &&
 		    (buf[0] | 0x20) == 'y')
@@ -381,10 +400,25 @@ main_init(char **argv, char **envp, SCRN **np)
 				if (!opened || opened == (void *)&opened)
 					opened = bw->parent;
 				maint->curwin = bw->parent;
+				closedall = 0;
 				if (er == -1 && bw->o.mnew)
 					exemac(bw->o.mnew);
 				if (er == 0 && bw->o.mold)
 					exemac(bw->o.mold);
+				if (closedall || leave) {
+					genjuppverstr();
+					/* blink substitution if possible */
+					if (n->mb)
+						n->mb = n->md ? n->md :
+						    n->us ? n->us : n->mb;
+					mdisp(n, n->li - 1, msgbuf);
+					nclose(n);
+					if (exmsg)
+						fprintf(stderr, "\n%s\n", exmsg);
+					else
+						putc('\n', stderr);
+					exit(main_rv);
+				}
 				maint->curwin = opened;
 				if (lnum > 0)
 					pline(bw->cursor, lnum - 1);
@@ -418,18 +452,7 @@ main_init(char **argv, char **envp, SCRN **np)
 		help_on(maint);
 	}
 	if (!nonotice) {
-		int uninvert = fdefault.hmsg &&
-		    fdefault.hmsg[0] == '\\' &&
-		    fdefault.hmsg[1] == 'i';
-
-		joe_snprintf_5((char *)msgbuf, JOE_MSGBUFSIZE,
-		    "\\i[ Joe's Own Editor v" VERSION
-		    " | %s | %s " JUPP_IS_COPYRIGHT_C_BY " ]%s%s%s",
-		    joe_mapname(locale_map),
-		    joe_maputf(locale_map) ? "©" : "(c)",
-		    uninvert ? "\\i " : fdefault.hmsg ? " " : "",
-		    uninvert ? fdefault.hmsg + 2 : fdefault.hmsg ?
-		    fdefault.hmsg : "", uninvert ? "" : "\\i");
+		genjuppverstr();
 		msgnw(lastw(maint)->object.base->parent, msgbuf);
 	}
 
@@ -437,8 +460,6 @@ main_init(char **argv, char **envp, SCRN **np)
 	return 0;
 }
 
-int main_rv;
-
 int
 main(int argc, char **argv, char **envp)
 {
