@@ -1,4 +1,3 @@
-/* $MirOS: contrib/code/jupp/menu.c,v 1.7 2017/01/10 19:16:27 tg Exp $ */
 /*
  *	Menu selection window
  *	Copyright
@@ -9,9 +8,12 @@
 #include "config.h"
 #include "types.h"
 
+__RCSID("$MirOS: contrib/code/jupp/menu.c,v 1.16 2018/01/06 00:28:31 tg Exp $");
+
 #include <stdlib.h>
 #include <string.h>
 
+#include "menu.h"
 #include "scrn.h"
 #include "utils.h"
 #include "va.h"
@@ -23,16 +25,18 @@ extern int dostaupd;
 
 static void mconfig(MENU *);
 
-static void menufllw(MENU *m)
+static void menufllw(jobject jO)
 {
+	MENU *m = jO.menu;
 	if (m->cursor < m->top)
 		m->top = m->cursor - m->cursor % m->perline;
 	else if (m->cursor >= m->top+m->perline*m->h)
 		m->top = m->cursor - m->cursor % m->perline - m->perline*(m->h-1);
 }
 
-static void menudisp(MENU *m)
+static void menudisp(jobject jO, int flg __attribute__((__unused__)))
 {
+	MENU *m = jO.menu;
 	int col;
 	int x;
 	int y;
@@ -49,7 +53,7 @@ static void menudisp(MENU *m)
 		col = 0;
 		for (x = 0; x != m->perline && y*m->perline+x+m->top<m->nitems; ++x) {
 			int atr;
-	
+
 			if (x + y*m->perline + m->top == m->cursor)
 				atr = INVERSE;
 			else
@@ -60,17 +64,17 @@ static void menudisp(MENU *m)
 
 			/* Generate field */
 			genfield(m->t->t,
-			         s + col,
-			         a + col,
-			         m->x + col,
-			         m->y + y,
-			         0,
-			         m->list[x + y*m->perline + m->top],
-			         strlen((char *)m->list[x + y*m->perline + m->top]),
-			         atr,
-			         m->width,
-			         0,
-				 NULL);
+			    s + col,
+			    a + col,
+			    m->x + col,
+			    m->y + y,
+			    0,
+			    m->list[x + y*m->perline + m->top],
+			    strlen((char *)m->list[x + y*m->perline + m->top]),
+			    atr,
+			    m->width,
+			    0,
+			    NULL);
 
 			col += m->width;
 
@@ -92,14 +96,16 @@ static void menudisp(MENU *m)
 	    (m->width + 1) + (col < m->width ? col : m->width);
 }
 
-static void menumove(MENU *m, int x, int y)
+static void menumove(jobject jO, int x, int y)
 {
+	MENU *m = jO.menu;
 	m->x = x;
 	m->y = y;
 }
 
-static void menuresz(MENU *m, int wi, int he)
+static void menuresz(jobject jO, int wi, int he)
 {
+	MENU *m = jO.menu;
 	m->w = wi;
 	m->h = he;
 }
@@ -222,7 +228,7 @@ int umdnarw(MENU *m)
 {
 	int col = m->cursor % m->perline;
 
-        m->cursor -= col;
+	m->cursor -= col;
 
 	if (m->cursor + m->perline < m->nitems) {
 		m->cursor += m->perline;
@@ -307,8 +313,9 @@ int umpgdn(MENU *m)
 
 }
 
-static int umrtn(MENU *m)
+static int umrtn(jobject jO)
 {
+	MENU *m = jO.menu;
 	dostaupd = 1;
 	if (m->func)
 		return m->func(m, m->cursor, m->object, 0);
@@ -324,8 +331,9 @@ int umbacks(MENU *m)
 		return -1;
 }
 
-static int umkey(MENU *m, int c)
+static int umkey(jobject jO, int c)
 {
+	MENU *m = jO.menu;
 	int x;
 	int n = 0;
 
@@ -341,7 +349,8 @@ static int umkey(MENU *m, int c)
 		else
 			return -1;
 	}
-	if (!(((c >= 'a') && (c <= 'z')) || ((c >= 'A') && (c <= 'Z'))))
+	c |= 0x20;
+	if (c < 'a' || c > 'z')
 		return -1;
 	c &= 0x1F;
 	for (x = 0; x != m->nitems; ++x)
@@ -353,7 +362,7 @@ static int umkey(MENU *m, int c)
 		for (x = 0; x != m->nitems; ++x)
 			if ((m->list[x][0] & 0x1F) == c) {
 				m->cursor = x;
-				return umrtn(m);
+				return umrtn(jO);
 			}
 	do {
 		++m->cursor;
@@ -364,15 +373,16 @@ static int umkey(MENU *m, int c)
 	return -1;
 }
 
-static int menuabort(MENU *m)
+static int menuabort(jobject jO)
 {
+	MENU *m = jO.menu;
 	W *w = m->parent;
-	int (*func) () = m->abrt;
+	jpoly_int *func = m->abrt;
 	void *object = m->object;
 	int x = m->cursor;
 	W *win = w->win;
 
-	joe_free(m);
+	free(m);
 	if (func)
 		return func(win->object, x, object);
 	else
@@ -380,7 +390,7 @@ static int menuabort(MENU *m)
 }
 
 WATOM watommenu = {
-	US "menu",
+	UC "menu",
 	menudisp,
 	menufllw,
 	menuabort,
@@ -400,7 +410,7 @@ void ldmenu(MENU *m, unsigned char **s, int cursor)
 	mconfig(m);
 }
 
-MENU *mkmenu(W *w, unsigned char **s, int (*func) (/* ??? */), int (*abrt) (/* ??? */), int (*backs) (/* ??? */), int cursor, void *object, int *notify)
+MENU *mkmenu(W *w, unsigned char **s, jpoly_int *func, jpoly_int *abrt, jpoly_int *backs, int cursor, void *object, int *notify)
 {
 	W *new;
 	MENU *m;
@@ -408,7 +418,7 @@ MENU *mkmenu(W *w, unsigned char **s, int (*func) (/* ??? */), int (*abrt) (/* ?
 	int h = (w->main->h*40) / 100; /* 40% of window size */
 	if (!h)
 		h = 1;
-	
+
 	if (s) {
 		lines = mlines(s,w->t->w-1);
 		if (lines < h)
@@ -423,7 +433,7 @@ MENU *mkmenu(W *w, unsigned char **s, int (*func) (/* ??? */), int (*abrt) (/* ?
 		return NULL;
 	}
 	wfit(new->t);
-	new->object = (void *) (m = (MENU *) joe_malloc(sizeof(MENU)));
+	new->object.menu = m = malloc(sizeof(MENU));
 	m->parent = new;
 	m->func = func;
 	m->abrt = abrt;
