@@ -8,7 +8,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/queue.c,v 1.6 2018/11/11 18:15:37 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/queue.c,v 1.7 2021/09/09 16:46:18 tg Exp $");
 
 #include <stdlib.h>
 
@@ -26,7 +26,7 @@ alitem(void *list, size_t itemsize)
 
 	if (qempty(STDITEM, link, freelist)) {
 		size_t num = 16;
-		unsigned char *i = malloc(itemsize * num);
+		unsigned char *i = calloc(num, itemsize);
 
 		while (num--) {
 			enquef(STDITEM, link, freelist, i);
