@@ -11,7 +11,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/rc.c,v 1.51 2020/10/29 23:57:40 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/rc.c,v 1.53 2022/07/20 22:51:23 tg Exp $");
 
 #include <string.h>
 #include <stdlib.h>
@@ -1014,7 +1014,7 @@ procrc(CAP *cap, const unsigned char *name)
 				/* do nothing */;
 			if (buf[0] != '}') {
 				err = 1;
-				fprintf(stderr, "\n%s:%d: End of rc file occurred before end of help text\n", name, line);
+				fprintf(stderr, "\n%s:%d: End of rc file occurred before end of help text", name, line);
 				break;
 			}
 			break;
