@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_REGEX_H
-#define _JOE_REGEX_H 1
+#ifndef JUPP_REGEX_H
+#define JUPP_REGEX_H
 
 #ifdef EXTERN_RC_C
-__IDSTRING(rcsid_regex_h, "$MirOS: contrib/code/jupp/regex.h,v 1.6 2017/12/06 23:02:04 tg Exp $");
+__IDSTRING(rcsid_regex_h, "$MirOS: contrib/code/jupp/regex.h,v 1.7 2020/03/27 06:38:58 tg Exp $");
 #endif
 
 int escape(int, unsigned char **, int *);
