@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_TAB_H
-#define _JOE_TAB_H 1
+#ifndef JUPP_TAB_H
+#define JUPP_TAB_H
 
 #ifdef EXTERN_UFILE_C
-__IDSTRING(rcsid_tab_h, "$MirOS: contrib/code/jupp/tab.h,v 1.5 2017/12/06 21:17:00 tg Exp $");
+__IDSTRING(rcsid_tab_h, "$MirOS: contrib/code/jupp/tab.h,v 1.6 2020/03/27 06:38:58 tg Exp $");
 #endif
 
 int cmplt(BW *bw);
