@@ -8,7 +8,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/termcap.c,v 1.28 2020/03/27 06:30:16 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/termcap.c,v 1.29 2022/07/20 22:31:18 tg Exp $");
 
 #include <sys/stat.h>
 #include <stdlib.h>
@@ -218,7 +218,7 @@ getcap(unsigned char *name, unsigned int baud, int (*out)(int))
 
  nextfile:
 	if (!npbuf[y]) {
-		fprintf(stderr, "Couldn't load termcap entry.  Using ansi default\n");
+		fprintf(stderr, "Couldn't load termcap entry; using ansi default\n");
 		ti = 0;
 		cap->tbuf = vsncpy(cap->tbuf, 0, sc(defentry));
 		goto checktc;
