@@ -8,7 +8,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/tty.c,v 1.38 2018/11/11 18:20:51 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/tty.c,v 1.39 2022/07/20 22:31:19 tg Exp $");
 
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -712,7 +712,7 @@ void ttgtsz(int *x, int *y)
  */
 static void ttshell(unsigned char *cmd);
 static const char shmsg[] =
-    "You are at the command shell.  Type 'exit' to return\n";
+    "You are at the command shell. Type 'exit' to return.\n";
 
 #if WANT_FORK
 #define v_or_fork() fork()
@@ -809,7 +809,7 @@ void ttsusp(void)
 	mpxsusp();
 #endif
 	ttclsn();
-	fprintf(stderr, "You have suspended the program.  Type 'fg' to return\n");
+	fprintf(stderr, "You have suspended the program. Type 'fg' to return.\n");
 	kill(0, SIGTSTP);
 	if (omode)
 		ttopnn();
