@@ -2,13 +2,15 @@
  *	Text editing windows
  *	Copyright
  *		(C) 1992 Joseph H. Allen
+ *	Copyright © 2004, 2007, 2010, 2016, 2017, 2018, 2022
+ *		mirabilos <m@mirbsd.org>
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/tw.c,v 1.24 2020/03/27 06:08:16 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/tw.c,v 1.26 2022/07/21 00:18:01 tg Exp $");
 
 #include <stdlib.h>
 #include <string.h>
@@ -42,8 +44,9 @@ char *ctime(const time_t *);
 
 extern int square;
 int staen = 0;
-int staupd = 0;
+unsigned char staupd = 0;
 int keepup = 0;
+unsigned char closedall = 0;
 
 /* Move text window */
 
@@ -556,7 +559,7 @@ int abortit(BW *bw)
 	w = bw->parent;
 	tw = (TW *) bw->object;
 	/* If only one main window on the screen... */
-	if (countmain(w->t) == 1)
+	if (countmain(w->t) == 1) {
 		/* Replace it with an orphaned buffer if there are any */
 		if ((b = borphan()) != NULL) {
 			void *object = bw->object;
@@ -569,6 +572,8 @@ int abortit(BW *bw)
 			bw->object = object;
 			return 0;
 		}
+		closedall = 1;
+	}
 	bwrm(bw);
 	vsrm(tw->stalin);
 	free(tw);
