@@ -9,7 +9,7 @@
 #include "config.h"
 #include "types.h"
 
-__RCSID("$MirOS: contrib/code/jupp/ufile.c,v 1.31 2018/01/18 22:00:31 tg Exp $");
+__RCSID("$MirOS: contrib/code/jupp/ufile.c,v 1.32 2022/07/20 22:31:19 tg Exp $");
 
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -321,7 +321,7 @@ static int saver(BW *bw, int c, struct savereq *req, int *notify)
 		}
 	}
 	if ((c | 0x20) != 'y') {
-		if (mkqw(bw->parent, sc("Could not make backup file.  Save anyway (y,n,^C)? "), saver, NULL, req, notify)) {
+		if (mkqw(bw->parent, sc("Could not make backup file. Save anyway (y,n,^C)? "), saver, NULL, req, notify)) {
 			return 0;
 		} else {
 			rmsavereq(req);
@@ -405,7 +405,7 @@ static int dosave2(BW *bw, int c, struct savereq *req, int *notify)
 		genexmsg(bw, 0, req->name);
 		rmsavereq(req);
 		return -1;
-	} else if (mkqw(bw->parent, sc("File exists.  Overwrite (y,n,^C)? "), dosave2, NULL, req, notify)) {
+	} else if (mkqw(bw->parent, sc("File exists. Overwrite (y,n,^C)? "), dosave2, NULL, req, notify)) {
 		return 0;
 	} else {
 		/* Should be in abort function */
@@ -425,7 +425,7 @@ static int dosave2a(BW *bw, int c, struct savereq *req, int *notify)
 		genexmsg(bw, 0, req->name);
 		rmsavereq(req);
 		return -1;
-	} else if (mkqw(bw->parent, sc("File on disk is newer.  Overwrite (y,n,^C)? "), dosave2a, NULL, req, notify)) {
+	} else if (mkqw(bw->parent, sc("File on disk is newer. Overwrite (y,n,^C)? "), dosave2a, NULL, req, notify)) {
 		return 0;
 	} else {
 		rmsavereq(req);
@@ -992,7 +992,7 @@ static int doquerysave(BW *bw,int c,struct savereq *req,int *notify)
 		return doquerysave(bw,0,req,notify);
 	} else {
 		unsigned char buf[1024];
-		joe_snprintf_1(buf,1024,"File %s has been modified.  Save it (y,n,^C)? ",bw->b->name ? bw->b->name : UC "(Unnamed)" );
+		joe_snprintf_1(buf, 1024, "File '%s' has been modified. Save it (y,n,^C)? ", bw->b->name ? bw->b->name : UC "(Unnamed)" );
 		if (mkqw(bw->parent, sz(buf), doquerysave, NULL, req, notify)) {
 			return 0;
 		} else {
