@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_USEARCH_H
-#define _JOE_USEARCH_H 1
+#ifndef JUPP_USEARCH_H
+#define JUPP_USEARCH_H
 
 #ifdef EXTERN_CMD_C
-__IDSTRING(rcsid_usearch_h, "$MirOS: contrib/code/jupp/usearch.h,v 1.5 2017/12/06 21:17:03 tg Exp $");
+__IDSTRING(rcsid_usearch_h, "$MirOS: contrib/code/jupp/usearch.h,v 1.6 2020/03/27 06:39:00 tg Exp $");
 #endif
 
 SRCH *mksrch(unsigned char *pattern, unsigned char *replacement, int ignore, int backwards, int repeat, int replace, int rest);
