@@ -5,11 +5,11 @@
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
-#ifndef _JOE_UTAG_H
-#define _JOE_UTAG_H 1
+#ifndef JUPP_UTAG_H
+#define JUPP_UTAG_H
 
 #ifdef EXTERN_CMD_C
-__IDSTRING(rcsid_utag_h, "$MirOS: contrib/code/jupp/utag.h,v 1.6 2017/12/06 23:17:36 tg Exp $");
+__IDSTRING(rcsid_utag_h, "$MirOS: contrib/code/jupp/utag.h,v 1.7 2020/03/27 06:39:00 tg Exp $");
 #endif
 
 int utag(BW *bw);
